# Kubejyg
## _Kubernetes Resource Extraction with Namespace Grouping ready for filtering with jq, yq and grep._

## Installation

## How it works

`kubejyg` allows you to extract `kubernets` resources across multiple namespaces and groups them by namespace without the need to write convoluted filters. The output is in `JSON` or `YAML`, ready to be fed into well known processors, `jq` and `yq`.

**Examples**


## Naming
**kubejyg** is named after the following utilities:
1. `kubectl`
2. `jq`
3. `yq`


## Features
